==> igniteui-react-16.16.2.tgz: package/esm5/lib/TreeItem.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
var TreeItem = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(TreeItem, _super);
    function TreeItem() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.b = new WCNativeHelper();
        _this.j = null;
        return _this;
    }
    Object.defineProperty(TreeItem.prototype, "c", {
        get: function () {
            return this.b;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(TreeItem.prototype, "nativeElement", {
        get: function () {
            return this.j;
        },
        set: function (a) {
            this.j = a;
            this.b.d = this.j;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(TreeItem.prototype, "a", {
        get: function () {
            var ret_ = this.c.c("parent");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.c.i("parent", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(TreeItem.prototype, "i", {
        get: function () {
            var ret_ = this.c.c("level");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.c.i("level", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(TreeItem.prototype, "m", {
        get: function () {
            var ret_ = this.c.c("label");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.c.i("label", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(TreeItem.prototype, "f", {
        get: function () {
            var ret_ = this.c.c("expanded");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.c.i("expanded", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(TreeItem.prototype, "d", {
        get: function () {
            var ret_ = this.c.c("active");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.c.i("active", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(TreeItem.prototype, "e", {
        get: function () {
            var ret_ = this.c.c("disabled");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.c.i("disabled", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(TreeItem.prototype, "h", {
        get: function () {
            var ret_ = this.c.c("selected");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.c.i("selected", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(TreeItem.prototype, "g", {
        get: function () {
            var ret_ = this.c.c("loading");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.c.i("loading", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(TreeItem.prototype, "l", {
        get: function () {
            var ret_ = this.c.c("value");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.c.i("value", value_);
        },
        enumerable: false,
        configurable: true
    });
    TreeItem.prototype.p = function () {
        this.nativeElement.connectedCallback();
    };
    TreeItem.prototype.q = function () {
        this.nativeElement.disconnectedCallback();
    };
    TreeItem.prototype.s = function () {
        this.nativeElement.expandWithEvent();
    };
    TreeItem.prototype.o = function () {
        this.nativeElement.collapseWithEvent();
    };
    TreeItem.prototype.t = function () {
        this.nativeElement.toggle();
    };
    TreeItem.prototype.r = function () {
        this.nativeElement.expand();
    };
    TreeItem.prototype.n = function () {
        this.nativeElement.collapse();
    };
    TreeItem.$t = markType(TreeItem, 'TreeItem', BaseElement.$);
    return TreeItem;
}(BaseElement));
export { TreeItem };

==> igniteui-react-18.5.1.tgz: package/esm5/lib/TreeItem.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
var TreeItem = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(TreeItem, _super);
    function TreeItem() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.c = new WCNativeHelper();
        _this.k = null;
        return _this;
    }
    Object.defineProperty(TreeItem.prototype, "d", {
        get: function () {
            return this.c;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(TreeItem.prototype, "nativeElement", {
        get: function () {
            return this.k;
        },
        set: function (a) {
            this.k = a;
            this.c.o = this.k;
        },
        enumerable: false,
        configurable: true
    });
    TreeItem.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(TreeItem.prototype, "b", {
        get: function () {
            var ret_ = this.d.m("parent", function (a) { return new TreeItem(); });
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.d.v("parent", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(TreeItem.prototype, "j", {
        get: function () {
            var ret_ = this.d.n("level");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.d.v("level", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(TreeItem.prototype, "n", {
        get: function () {
            var ret_ = this.d.n("label");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.d.v("label", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(TreeItem.prototype, "g", {
        get: function () {
            var ret_ = this.d.n("expanded");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.d.v("expanded", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(TreeItem.prototype, "e", {
        get: function () {
            var ret_ = this.d.n("active");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.d.v("active", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(TreeItem.prototype, "f", {
        get: function () {
            var ret_ = this.d.n("disabled");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.d.v("disabled", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(TreeItem.prototype, "i", {
        get: function () {
            var ret_ = this.d.n("selected");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.d.v("selected", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(TreeItem.prototype, "h", {
        get: function () {
            var ret_ = this.d.n("loading");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.d.v("loading", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(TreeItem.prototype, "m", {
        get: function () {
            var ret_ = this.d.n("value");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.d.v("value", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(TreeItem.prototype, "a", {
        get: function () {
            var ret_ = this.d.m("path", function (a) { return new TreeItem(); });
            return ret_;
        },
        enumerable: false,
        configurable: true
    });
    TreeItem.prototype.q = function () {
        this.nativeElement.connectedCallback();
    };
    TreeItem.prototype.r = function () {
        this.nativeElement.disconnectedCallback();
    };
    TreeItem.prototype.t = function () {
        this.nativeElement.expandWithEvent();
    };
    TreeItem.prototype.p = function () {
        this.nativeElement.collapseWithEvent();
    };
    TreeItem.prototype.v = function () {
        this.nativeElement.toggle();
    };
    TreeItem.prototype.s = function () {
        this.nativeElement.expand();
    };
    TreeItem.prototype.o = function () {
        this.nativeElement.collapse();
    };
    TreeItem.$t = markType(TreeItem, 'TreeItem', BaseElement.$);
    return TreeItem;
}(BaseElement));
export { TreeItem };
